import os
import json
import locator

"""
This helper class loads up the configuration file and serves its data

The data is:
ip, port : our local address
LISTEN_READ_BYTES: the bytes the listener will try to read at an incoming connection
MAX_SIMULTANEOUS_CONNECTIONS: how many incoming connections do we accept simultaneously
LISTEN_TIMEOUT_SECONDS: timeout for the listener i.e it will drop client connection if nothing happens for this many seconds)
"SERVER_SEND_PACKAGE_SIZE": How big chunks the server will use to send back data, don't put it too high or you'll choke some buffers here
"MAX_STORAGE_SPACE_OTHER_MB": 1024   How many Mb we'll use to store other peoples files
"SWICHAROO_POLICY": "MAX_DOUBLE"  : How do we negociate switching one of our files versus one of another nodes files
"SWICHAROO_MINSIZE_ACCEPT_ALL" 65536 : Files under this size are always accepted in a swicharoo
"SWICHAROO_FILE_MAXSIZE_KB": 32768  : Files bigger than this are always rejected

"""


class Configuration:
    def __init__(self):
        path = 'config.json'
        if os.path.isfile(path):
            with open(os.path.join(locator.module_path(), path), 'r') as f:
                self.data = json.load(f)
        else:
            self.data = None

    def get(self, name, default=None):
        if self.data:
            if name in self.data:
                return self.data[name]
        return default
